# teamgun

```bash
$ pip install teamgun1
```

```bash
$ ha-weather
현재 위치: 동작구 신대방2동
현재 날씨: 구름많음
현재 온도: 17.7°

$ news
주요 뉴스 헤드라인:

주요뉴스

 어릴 적 동네 골목에 있던 이 곳이 살아났다
 “키움증권, 이익훼손돼도 지배구조상 주주환원 확대 가능성↑”[투자360]
 "시장 급락에 대응하는 자세"...한국경제TV 대박천국 '이동근 종가해결첵(CHECK)'
 증권사 "영풍제지 불똥 튈라" 리스크 관리 강화… 급등주 미수 차단
 주가조작 영풍제지?대양금속...거래 풀려도 연쇄 '반대매매' 위기
 작심하고 카카오 비판 나선 이복현 금감원장, 무엇을 노리나?

주요뉴스 더보기
```
